diff --git a/gnu/packages/hardware.scm b/gnu/packages/hardware.scm
index cfd667d757..8d06920b79 100644
--- a/gnu/packages/hardware.scm
+++ b/gnu/packages/hardware.scm
@@ -1160,48 +1160,48 @@ (define-public usbguard
                (base32 "0lpyhkz5nr0c9mq57mgcvam5c8qfqqwjc4xd46n2ldqc9vhfsask"))))
     (build-system gnu-build-system)
     (arguments
-     '(#:phases
-       (modify-phases %standard-phases
-         (add-after 'unpack 'patch-bootstrap-script
-           (lambda _
-             ;; Don't attempt to fetch git submodules.
-             (substitute* "autogen.sh"
-               (("^git submodule.*")
-                ""))))
-         (add-after 'bootstrap 'patch-build-scripts
-           (lambda* (#:key inputs #:allow-other-keys)
-             (substitute* "configure"
-               (("/usr/include/catch")
-                (dirname (search-input-file inputs "include/catch.hpp"))))
-             ;; Do not create log directory.
-             (substitute* "Makefile.in" ((".*/log/usbguard.*") ""))
-             ;; Disable LDAP tests: they use 'sudo'.
-             (substitute* "src/Tests/Makefile.in"
-               (("\\$\\(am__append_2\\)") ""))))
-         (add-after 'install 'delete-static-library
-           (lambda* (#:key outputs #:allow-other-keys)
-             ;; It can't be direclty disabled since it's needed for the tests.
-             (delete-file (string-append (assoc-ref outputs "out")
-                                         "/lib/libusbguard.a"))))
-         (add-after 'install 'install-zsh-completion
-           (lambda* (#:key outputs #:allow-other-keys)
-             (let* ((out (assoc-ref outputs "out"))
-                    (site-functions
-                     (string-append out "/share/zsh/site-functions")))
-               (mkdir-p site-functions)
-               (copy-file "scripts/usbguard-zsh-completion"
-                          (string-append site-functions "/_usbguard"))))))
-       #:make-flags
-       (list (string-append "BASH_COMPLETION_DIR="
-                            (assoc-ref %outputs "out")
-                            "/etc/bash_completion.d"))
-       #:configure-flags
-       (list
-        "--localstatedir=/var"
-        "--enable-systemd=no"
-        "--with-ldap"
-        "--with-dbus"
-        "--with-polkit")))
+     (list
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-after 'unpack 'patch-bootstrap-script
+            (lambda _
+              ;; Don't attempt to fetch git submodules.
+              (substitute* "autogen.sh"
+                (("^git submodule.*")
+                 ""))))
+          (add-after 'bootstrap 'patch-build-scripts
+            (lambda* (#:key inputs #:allow-other-keys)
+              (substitute* "configure"
+                (("/usr/include/catch")
+                 (dirname (search-input-file inputs "include/catch.hpp"))))
+              ;; Do not create log directory.
+              (substitute* "Makefile.in" ((".*/log/usbguard.*") ""))
+              ;; Disable LDAP tests: they use 'sudo'.
+              (substitute* "src/Tests/Makefile.in"
+                (("\\$\\(am__append_2\\)") ""))))
+          (add-after 'install 'delete-static-library
+            (lambda args
+              ;; It can't be directly disabled since it's needed for the tests.
+              (delete-file (string-append #$output
+                                          "/lib/libusbguard.a"))))
+          (add-after 'install 'install-zsh-completion
+            (lambda args
+              (let ((site-functions
+                     (string-append #$output "/share/zsh/site-functions")))
+                (mkdir-p site-functions)
+                (copy-file "scripts/usbguard-zsh-completion"
+                           (string-append site-functions "/_usbguard"))))))
+      #:make-flags
+      #~(list (string-append "BASH_COMPLETION_DIR="
+                             #$output
+                             "/etc/bash_completion.d"))
+      #:configure-flags
+      #~(list
+         "--localstatedir=/var"
+         "--enable-systemd=no"
+         "--with-ldap"
+         "--with-dbus"
+         "--with-polkit")))
     (inputs
      (list audit
            catch-framework
